function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import isEqual from 'lodash/fp/isEqual';
import { withStyles } from '@material-ui/styles';
import Grid from '@material-ui/core/Grid';

const styles = theme => ({
  itemFormContainer: {}
});

class FormElements extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      components: this.props.describe.fields.filter(f => f.deprecatedAndHidden !== true).map((f, index) => {
        let xsLength = 12 / this.props.columns;

        if (f.length >= 256 && this.props.displayType !== 'filter') {
          xsLength = 12;
        }

        return React.createElement(Grid, {
          item: true,
          key: f.name ? f.name : index,
          xs: xsLength,
          style: {
            whiteSpace: this.props.noWrap ? 'nowrap' : 'inherit'
          }
        }, React.createElement("svg", {
          width: "100%",
          height: this.props.svgHeight / 2,
          style: {
            paddingTop: this.props.svgHeight / 4,
            paddingBottom: this.props.svgHeight / 4
          }
        }, React.createElement("rect", {
          rx: "10",
          ry: "10",
          width: "100%",
          height: "100%",
          style: {
            opacity: 0.15
          }
        }), "Loading..."));
      })
    });

    _defineProperty(this, "componentIsUnmounted", false);
  }

  async componentDidMount() {
    const components = await this.getComponents();
    this.setComponentsToState(components);
    this.props.onFormLoad();
  }

  async componentDidUpdate(prevProps) {
    if (!isEqual(this.props)(prevProps)) {
      const components = await this.getComponents();
      this.setComponentsToState(components);
    }
  }

  shouldComponentUpdate(nextProps, nextState) {
    return !isEqual(this.state)(nextState) || !isEqual(this.props)(nextProps);
  }

  componentWillUnmount() {
    this.componentIsUnmounted = true;
  }

  async getComponents() {
    const components = await Promise.all(this.props.describe.fields.filter(f => f.deprecatedAndHidden !== true).map(async (f, index) => {
      const Component = await import(`./fields/${f.type}${this.props.displayType ? `/${this.props.displayType}` : ''}`);
      let disabled = false;

      if (this.props.isNewItem && !f.createable) {
        disabled = true;
      }

      if (!this.props.isNewItem && !f.updateable) {
        disabled = true;
      }

      if (f.createable == null && f.updateable == null) {
        disabled = false;
      }

      const validate = !this.props.displayType && !disabled ? await import(`./fields/${f.type}/validation`) : undefined;
      const validation = validate ? validate.default(f) : undefined;
      const validateOnChange = validate && !disabled ? validate.validateOnChange : false;
      const validateOnBlur = validate && !disabled ? validate.validateOnBlur : false; // Does the outer compound field have validation?
      // If so pass the inner field to it

      const compoundValidation = this.props.validate;
      let combinedValidation;

      if (compoundValidation) {
        combinedValidation = (value, values) => {
          const innerFieldErrors = validation(value, values);
          const outerFieldErrors = compoundValidation(value, values, f);
          if (innerFieldErrors) return innerFieldErrors;
          if (outerFieldErrors) return outerFieldErrors;
        };
      }

      const autoFocus = index === 0 && this.props.autoFocus === true || undefined;
      let xsLength = 12 / this.props.columns;

      if (f.length >= 256 && this.props.displayType !== 'filter') {
        xsLength = 12;
      }

      const component = React.createElement(Component.default, {
        key: f.name ? f.name : index,
        field: f.name,
        autoFocus: autoFocus,
        t: this.props.t,
        i18n: this.props.i18n,
        displayType: this.props.displayType,
        describe: f,
        type: f.type,
        noRequired: this.props.noRequired,
        isNewItem: this.props.isNewItem,
        shrink: this.props.shrink,
        underline: this.props.underline,
        spacing: this.props.spacing,
        noWrap: this.props.noWrap,
        svgHeight: this.props.svgHeight,
        lookupIdFromItem: this.props.lookupIdFromItem,
        lookup: this.props.lookup,
        lookupQry: this.props.lookupQry,
        validate: !this.props.noRequired && (combinedValidation || validation),
        validateOnChange: !this.props.noRequired && validateOnChange == null && true,
        validateOnBlur: !this.props.noRequired && validateOnBlur == null && true // onFormLoad={this.props.onFormLoad}
        ,
        onChange: this.props.onChange,
        onBlur: this.props.onBlur,
        xsLength: xsLength,
        apiKey: this.props.apiKey,
        searchClasses: f.type === 'search' ? this.props.searchClasses : undefined
      });

      if (this.props.displayType === 'display') {
        return component;
      }

      return React.createElement(Grid, {
        item: true,
        key: f.name ? f.name : index,
        xs: xsLength,
        style: {
          whiteSpace: this.props.noWrap ? 'nowrap' : 'inherit'
        }
      }, component);
    }));
    return components;
  }

  setComponentsToState(components) {
    if (!this.componentIsUnmounted) {
      this.setState({
        components
      }, () => {});
    }
  }

  render() {
    const {
      classes,
      spacing
    } = this.props;
    const {
      components
    } = this.state;
    return React.createElement(Grid, {
      container: true,
      spacing: spacing,
      className: classes.itemFormContainer,
      alignItems: "stretch"
    }, components);
  }

}

export default withStyles(styles)(FormElements);