function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { Form } from 'informed';
import LuxonUtils from '@date-io/luxon';
import { MuiPickersUtilsProvider } from '@material-ui/pickers';
import FormElements from './FormElements';
import LayoutContainer from './Layout';

const ItemForm = ({
  columns = 2,
  layout,
  describe,
  t = v => v,
  i18n = {
    language: 'en'
  },
  lookupIdFromItem = item => item ? item.itemId : null,
  lookup = async itemId => ({
    itemId,
    label: itemId
  }),
  lookupQry = async () => {
    throw Error('err::noLookupProvided');
  },
  displayType = '',
  item,
  children,
  onSubmit,
  noRequired,
  isNewItem = false,
  spacing = 2,
  shrink,
  underline = true,
  noWrap = false,
  svgHeight = 44,
  onChange = () => null,
  onBlur = () => null,
  onFormLoad = () => null,
  onExpandedChange = () => null,
  defaultExpanded = [0],
  apiKey = '',
  searchClasses,
  getApi = formApi => null
}) => {
  if (columns < 0 || 12 / columns % 1 !== 0 && columns !== 0) {
    console.error('Columns required to be one of the following: 1, 2, 3, 4, 6, 12.');
    return;
  }

  if (spacing < 0 || spacing > 8) {
    return console.warn('err::deformed::spacing') || null;
  }

  const initialValues = _objectSpread({}, getDefaultValues(describe), {}, item);

  return React.createElement(MuiPickersUtilsProvider, {
    utils: LuxonUtils
  }, React.createElement(Form, {
    getApi: formApi => getApi(formApi),
    initialValues: initialValues,
    onSubmit: onSubmit
  }, ({
    formApi,
    formState
  }) => children({
    formState,
    formApi,
    fields: layout ? React.createElement(LayoutContainer, {
      columns: columns,
      layout: layout,
      describe: describe,
      t: t,
      i18n: i18n,
      displayType: displayType,
      noRequired: noRequired,
      isNewItem: isNewItem,
      spacing: spacing,
      shrink: shrink,
      underline: underline,
      noWrap: noWrap,
      svgHeight: svgHeight,
      lookupIdFromItem: lookupIdFromItem,
      lookup: lookup,
      lookupQry: lookupQry,
      onChange: onChange,
      onBlur: onBlur,
      onFormLoad: onFormLoad,
      formState: formState,
      defaultExpanded: defaultExpanded,
      onExpandedChange: onExpandedChange,
      apiKey: apiKey,
      searchClasses: searchClasses
    }) : React.createElement(FormElements, {
      columns: columns,
      describe: describe,
      t: t,
      i18n: i18n,
      displayType: displayType,
      noRequired: noRequired,
      isNewItem: isNewItem,
      spacing: spacing,
      shrink: shrink,
      underline: underline,
      noWrap: noWrap,
      svgHeight: svgHeight,
      lookupIdFromItem: lookupIdFromItem,
      lookup: lookup,
      lookupQry: lookupQry,
      onChange: onChange,
      onBlur: onBlur,
      onFormLoad: onFormLoad,
      apiKey: apiKey,
      searchClasses: searchClasses
    }),
    fieldProps: {
      columns,
      t,
      i18n,
      displayType,
      noRequired,
      isNewItem,
      spacing,
      shrink,
      underline,
      noWrap,
      svgHeight,
      lookupIdFromItem,
      lookup,
      lookupQry,
      onFormLoad,
      onChange,
      onBlur,
      apiKey,
      searchClasses
    }
  })));
};

export default ItemForm;

function getDefaultValues(describe) {
  if (!describe || !describe.fields || !describe.fields.length) return {};
  return describe.fields.reduce((dv, f) => {
    if (f.defaultValue) {
      return _objectSpread({}, dv, {
        [f.name]: f.defaultValue
      });
    }

    return dv;
  }, {});
}