import React from 'react';
import isEqual from 'lodash/fp/isEqual'; // import Grid from '@material-ui/core/Grid'

import { withStyles } from '@material-ui/styles';
import ExpansionPanel from '@material-ui/core/ExpansionPanel';
import ExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary';
import ExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails';
import Typography from '@material-ui/core/Typography';
import ExpandMore from '@material-ui/icons/ExpandMore';
import FormElements from '../FormElements';

const styles = theme => ({
  noTransition: {
    transition: 'none'
  },
  noPaper: {
    boxShadow: 'none'
  }
});

class LayoutContainer extends React.Component {
  shouldComponentUpdate(nextProps) {
    const {
      formState,
      layout,
      describe,
      displayType
    } = this.props;
    const {
      formState: nextFormState,
      layout: nextLayout,
      describe: nextDescribe,
      displayType: nextDisplayType
    } = nextProps;

    if (this.props === nextProps) {
      return false;
    }

    if (isEqual(displayType)(nextDisplayType) && isEqual(formState)(nextFormState) && isEqual(layout)(nextLayout) && isEqual(describe)(nextDescribe)) {
      return false;
    }

    return true;
  }

  componentDidMount() {
    this.props.onFormLoad();
  }

  render() {
    const {
      classes,
      columns,
      layout,
      describe,
      t,
      i18n,
      displayType,
      noRequired,
      isNewItem,
      spacing,
      shrink,
      underline,
      noWrap,
      svgHeight,
      lookupIdFromItem,
      lookup,
      lookupQry,
      onChange,
      // onFormLoad,
      formState,
      defaultExpanded,
      onExpandedChange,
      apiKey,
      searchClasses
    } = this.props;
    const groupedDescribes = layout.sections.map(sec => {
      return {
        fields: sec.fields.map(f => {
          return describe.fields.find(df => df.name === f.name);
        }).filter(f => f),
        heading: sec.heading
      };
    });
    const errors = formState.errors;
    return React.createElement(React.Fragment, null, groupedDescribes.map((gd, i) => {
      const groupError = gd.fields.filter(field => {
        if (field.type === 'compound') {
          return field.fields.filter(cField => Object.keys(errors).includes(cField.name)).length;
        }

        return Object.keys(errors).includes(field.name);
      }).length;
      return (// <Grid item xs={12}>
        React.createElement(ExpansionPanel, {
          className: classes.noPaper,
          defaultExpanded: defaultExpanded.includes(gd.heading) || defaultExpanded.includes(i),
          key: `${gd.heading}-${i}`,
          onChange: (event, expanded) => onExpandedChange(gd.heading, expanded, i)
        }, React.createElement(ExpansionPanelSummary, {
          className: classes.noTransition,
          expandIcon: React.createElement(ExpandMore, null)
        }, React.createElement(Typography, {
          variant: "body1",
          color: groupError ? 'error' : 'textSecondary'
        }, gd.heading)), React.createElement(ExpansionPanelDetails, null, React.createElement(FormElements, {
          columns: columns,
          describe: gd,
          t: t,
          i18n: i18n,
          displayType: displayType,
          noRequired: noRequired,
          isNewItem: isNewItem,
          spacing: spacing,
          shrink: shrink,
          underline: underline,
          noWrap: noWrap,
          svgHeight: svgHeight,
          lookupIdFromItem: lookupIdFromItem,
          lookup: lookup,
          lookupQry: lookupQry,
          onFormLoad: () => null,
          onChange: onChange,
          apiKey: apiKey,
          searchClasses: searchClasses
        }))) // </Grid>

      );
    }));
  }

}

export default withStyles(styles)(LayoutContainer);