function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { asField } from 'informed';
import Checkbox from '@material-ui/core/Checkbox';
import FormControl from '@material-ui/core/FormControl';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import Grid from '@material-ui/core/Grid';
import FilterFieldContainer from '../../utils/FilterFieldContainer';
import booleanDropdownItems from '../../utils/booleanDropdownItems';
const filters = {
  Equals: [{
    type: 'Boolean',
    label: '',
    key: '$eq'
  }],
  'HasAnyValue': [{
    type: 'Text',
    label: 'HasAnyValue',
    key: '$exists'
  }],
  'HasNoValue': [{
    type: 'Text',
    label: 'HasNoValue',
    key: '$exists'
  }]
};

class BooleanFilterFieldItem extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      filterType: this.props.fieldState.value ? this.props.fieldState.value.type || 'Equals' : 'Equals',
      $eq: this.props.fieldState.value ? this.props.fieldState.value.$eq : undefined,
      $exists: this.props.fieldState.value ? this.props.fieldState.value.$exists : undefined
    });
  }

  componentDidMount() {
    if (!this.props.fieldState.value) {
      this.handleOnChange('$eq', false);
    }
  }

  handleSetValue() {
    this.props.fieldApi.setValue({
      type: this.state.filterType,
      $eq: this.state.$eq,
      $exists: this.state.$exists
    });
  }

  handleChangeFilter(filter) {
    this.setState({
      filterType: filter,
      $eq: undefined,
      $exists: filter === 'HasAnyValue' || filter === 'HasNoValue' ? filter === 'HasAnyValue' : undefined
    }, () => this.handleSetValue());
  }

  handleOnChange(key, value) {
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  handleOnBlur(key, value) {
    this.props.fieldApi.setTouched();
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  render() {
    const _this$props = this.props,
          {
      fieldState,
      fieldApi,
      describe,
      t,
      i18n,
      shrink,
      underline,
      spacing
    } = _this$props,
          props = _objectWithoutProperties(_this$props, ["fieldState", "fieldApi", "describe", "t", "i18n", "shrink", "underline", "spacing"]);

    const {
      value
    } = fieldState;
    const {
      setValue,
      setTouched
    } = fieldApi;
    const {
      onChange,
      onBlur
    } = props;
    const {
      filterType
    } = this.state;
    return React.createElement(FilterFieldContainer, {
      t: t,
      filterList: booleanDropdownItems,
      filterChange: filter => this.handleChangeFilter(filter)
    }, React.createElement(Grid, {
      container: true,
      spacing: spacing,
      alignItems: "flex-end"
    }, React.createElement(Grid, {
      item: true,
      xs: 4
    }, describe.label, ":"), filters[filterType] && filters[filterType].map(ft => {
      const filterColumns = filters[filterType].length > 2 ? 2 : filters[filterType].length;

      if (ft.type === 'Boolean') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, React.createElement(FieldItemIndividual, {
          label: t(ft.label),
          describe: describe,
          value: this.state[ft.key],
          onChange: value => this.handleOnChange(ft.key, value),
          onBlur: value => this.handleOnBlur(ft.key, value),
          shrink: shrink,
          underline: underline
        }));
      }

      if (ft.type === 'Text') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, ft.label);
      }

      return 'err::invalidFilterType';
    })));
  }

}

export default asField(BooleanFilterFieldItem);

function FieldItemIndividual({
  label,
  value,
  onChange,
  onBlur,
  describe,
  shrink,
  underline
}) {
  const {
    name,
    type,
    // label, // not used in filter
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    encrypted,
    bytelength,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    extraTypeInfo,
    // e.g text area and rich text area are about the same. This would say rich text area to differentiate
    inlineHelpText,
    deprecatedAndHidden // if this is true this component should not return anything. - Grid

  } = describe;
  return React.createElement(FormControl, {
    fullWidth: true
  }, React.createElement(FormControlLabel, {
    control: React.createElement(Checkbox, {
      checked: !!value,
      name: name,
      color: "primary",
      onChange: e => onChange(e.target.checked),
      onBlur: e => onBlur(e.target.checked) // indeterminate={value == null}

    }),
    label: "",
    style: {
      marginLeft: 0
    }
  }));
}

function changeHandler(currentValue) {
  if (currentValue) {
    return false;
  }

  if (currentValue == null) {
    return true;
  }

  return null;
}