function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import uniq from 'lodash/fp/uniq';
import Grid from '@material-ui/core/Grid';
import { asField } from 'informed';
import { DatePicker } from '@material-ui/pickers';
import { DateTime } from 'luxon';
import ArrowLeft from '@material-ui/icons/ArrowLeft';
import ArrowRight from '@material-ui/icons/ArrowRight';
import Event from '@material-ui/icons/Event';
import InputAdornment from '@material-ui/core/InputAdornment';
import IconButton from '@material-ui/core/IconButton';
import TextField from '@material-ui/core/TextField';
import FilterFieldContainer from '../../utils/FilterFieldContainer';
import semanticFilters from '../../utils/semanticList';

const filters = _objectSpread({
  Between: [{
    type: 'DateField',
    label: 'GreaterThan',
    key: '$gte'
  }, {
    type: 'DateField',
    label: 'LessThan',
    key: '$lte'
  }],
  Outside: [{
    type: 'DateField',
    label: 'LessThan',
    key: '$lte'
  }, {
    type: 'DateField',
    label: 'GreaterThan',
    key: '$gte'
  }],
  'Greater Than': [{
    type: 'DateField',
    label: 'Greater Than',
    key: '$gte'
  }],
  'Less Than': [{
    type: 'DateField',
    label: 'Less Than',
    key: '$lte'
  }],
  'HasAnyValue': [{
    type: 'Text',
    label: 'HasAnyValue',
    key: '$exists'
  }],
  'HasNoValue': [{
    type: 'Text',
    label: 'HasNoValue',
    key: '$exists'
  }],
  Exactly: [{
    type: 'DateField',
    label: 'Exactly',
    key: '$exact'
  }]
}, semanticFilters);

const keys = uniq([...Object.keys(filters).flatMap(f => filters[f].map(filter => filter.key))]);

class DateFilterFieldItem extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", _objectSpread({
      filterType: this.props.fieldState.value && this.props.fieldState.value.type || 'Between'
    }, keys.reduce((acc, key) => _objectSpread({}, acc, {
      [key]: this.props.fieldState.value && this.props.fieldState.value[key] || undefined
    }), {})));
  }

  handleSetValue() {
    this.props.fieldApi.setValue(_objectSpread({
      type: this.state.filterType
    }, keys.reduce((acc, key) => _objectSpread({}, acc, {
      [key]: this.state[key]
    }), {})));
  }

  handleChangeFilter(filter) {
    const newState = _objectSpread({
      filterType: filter
    }, keys.reduce((acc, key) => _objectSpread({}, acc, {
      [key]: undefined
    }), {}), {
      $exists: filter === 'HasAnyValue' || filter === 'HasNoValue' ? filter === 'HasAnyValue' : undefined
    });

    if (Object.keys(semanticFilters).includes(filter)) {
      semanticFilters[filter].forEach(field => {
        newState[field.key] = 1;
      });
    }

    this.setState(newState, () => this.handleSetValue());
  }

  handleOnChange(key, value) {
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  handleOnBlur(key, value) {
    this.props.fieldApi.setTouched();
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  render() {
    const _this$props = this.props,
          {
      fieldState,
      fieldApi,
      describe,
      t,
      i18n,
      shrink,
      underline,
      spacing
    } = _this$props,
          props = _objectWithoutProperties(_this$props, ["fieldState", "fieldApi", "describe", "t", "i18n", "shrink", "underline", "spacing"]);

    const {
      value
    } = fieldState;
    const {
      setValue,
      setTouched
    } = fieldApi;
    const {
      onChange,
      onBlur
    } = props;
    const {
      filterType
    } = this.state;
    return React.createElement(FilterFieldContainer, {
      t: t,
      filterList: Object.keys(filters),
      filterChange: filter => this.handleChangeFilter(filter)
    }, React.createElement(Grid, {
      container: true,
      spacing: spacing,
      alignItems: "flex-end"
    }, React.createElement(Grid, {
      item: true,
      xs: 4
    }, describe.label, ":"), filters[filterType] && filters[filterType].map(ft => {
      const filterColumns = filters[filterType].length > 2 ? 2 : filters[filterType].length;

      if (ft.type === 'DateField') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, React.createElement(FieldItemIndividual, {
          t: t,
          label: t(ft.label),
          describe: describe,
          value: this.state[ft.key] ? this.state[ft.key] : '',
          onChange: value => this.handleOnChange(ft.key, value),
          onBlur: value => this.handleOnBlur(ft.key, value),
          shrink: shrink,
          underline: underline
        }));
      }

      if (ft.type === 'TextField') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, React.createElement(FieldItemIndividualText, {
          t: t,
          label: t(ft.label),
          describe: describe,
          value: this.state[ft.key] ? this.state[ft.key] : '',
          onChange: value => this.handleOnChange(ft.key, value),
          onBlur: value => this.handleOnBlur(ft.key, value),
          shrink: shrink,
          underline: underline
        }));
      }

      if (ft.type === 'Text') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, ft.label);
      }

      return 'err::invalidFilterType';
    })));
  }

}

export default asField(DateFilterFieldItem);

function FieldItemIndividual({
  t,
  label,
  value,
  onChange,
  onBlur,
  describe,
  shrink,
  underline
}) {
  const {
    name,
    type,
    // label, // not used in filter
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    encrypted,
    bytelength,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    extraTypeInfo,
    // e.g text area and rich text area are about the same. This would say rich text area to differentiate
    inlineHelpText,
    deprecatedAndHidden // if this is true this component should not return anything. - Grid

  } = describe;
  let val = value;

  if (!val || val === '') {
    val = null;
  }

  if (val) {
    val = DateTime.fromFormat(val, 'yyyy-LL-dd').toLocal().minus({
      minutes: DateTime.local().offset
    });
  }

  return React.createElement(DatePicker, {
    value: val,
    label: label,
    name: name,
    format: "DD",
    onChange: e => onChange(e ? e.toFormat('yyyy-LL-dd') : '') // onBlur={e => onBlur(e.target.value)}
    ,
    placeholder: inlineHelpText,
    type: !encrypted ? 'text' : 'password',
    fullWidth: true,
    autoOk: true,
    clearable: nillable,
    cancelLabel: t('Cancel'),
    clearLabel: t('Clear'),
    emptyLabel: "",
    invalidLabel: t('err::invalid_date'),
    okLabel: t('Ok'),
    leftArrowIcon: React.createElement(ArrowLeft, null),
    rightArrowIcon: React.createElement(ArrowRight, null),
    InputLabelProps: {
      shrink: shrink ? true : undefined
    },
    InputProps: {
      disableUnderline: !underline,
      endAdornment: React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(IconButton, null, React.createElement(Event, null)))
    }
  });
}

function FieldItemIndividualText({
  label,
  value,
  onChange,
  onBlur,
  describe,
  shrink,
  underline
}) {
  const {
    name,
    type,
    // label, // not used in filter
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    encrypted,
    bytelength,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    extraTypeInfo,
    // e.g text area and rich text area are about the same. This would say rich text area to differentiate
    inlineHelpText,
    deprecatedAndHidden // if this is true this component should not return anything. - Grid

  } = describe;
  return React.createElement(TextField, {
    value: value,
    label: label,
    name: name,
    type: "number",
    placeholder: inlineHelpText,
    InputLabelProps: {
      shrink: shrink ? true : undefined
    },
    InputProps: {
      disableUnderline: !underline
    },
    onChange: e => onChange(e.target.value),
    onBlur: e => onBlur(e.target.value),
    fullWidth: true
  });
}