function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import { DatePicker } from '@material-ui/pickers';
import { DateTime } from 'luxon';
import { asField } from 'informed';
import ArrowLeft from '@material-ui/icons/ArrowLeft';
import ArrowRight from '@material-ui/icons/ArrowRight';
import Event from '@material-ui/icons/Event';
import InputAdornment from '@material-ui/core/InputAdornment';
import IconButton from '@material-ui/core/IconButton';
export const DateFieldItem = (_ref) => {
  let {
    fieldState,
    fieldApi,
    describe,
    t,
    i18n,
    noRequired,
    isNewItem,
    maxLines,
    shrink,
    underline
  } = _ref,
      props = _objectWithoutProperties(_ref, ["fieldState", "fieldApi", "describe", "t", "i18n", "noRequired", "isNewItem", "maxLines", "shrink", "underline"]);

  const {
    value,
    pristine,
    error
  } = fieldState;
  const {
    setValue,
    setTouched
  } = fieldApi;
  const {
    onChange,
    onBlur,
    autoFocus
  } = props;
  const {
    name,
    type,
    label,
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    encrypted,
    bytelength,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    extraTypeInfo,
    // e.g text area and rich text area are about the same. This would say rich text area to differentiate
    inlineHelpText,
    deprecatedAndHidden // if this is true this component should not return anything. - Grid

  } = describe;
  let disabled = false;

  if (isNewItem && !createable) {
    disabled = true;
  }

  if (!isNewItem && !updateable) {
    disabled = true;
  }

  if (createable == null && updateable == null) {
    disabled = false;
  }

  const errors = error && !!error.length;
  const helperText = errors ? error.map(e => t(e)).join(', ') : null;
  const multiLine = parseInt(maxLines, 10) > 1 || false;
  const lines = parseInt(maxLines, 10) || 1;
  let val = !value && value !== 0 ? '' : value;

  if (pristine && isNewItem) {
    val = defaultValue;
  }

  if (!val || val === '') {
    val = null;
  }

  if (val) {
    val = DateTime.fromISO(val).toLocal().minus({
      minutes: DateTime.local().offset
    });
  }

  return React.createElement(DatePicker, {
    value: val,
    disabled: disabled,
    error: errors,
    helperText: helperText // this goes below the line
    ,
    label: label,
    name: name,
    format: "DD",
    onChange: e => {
      setValue(e ? e.toFormat('yyyy-LL-dd') : '');

      if (onChange) {
        onChange(e, {}, describe);
      }

      if (onBlur) {
        onBlur(e, {}, describe);
      }
    },
    placeholder: inlineHelpText,
    required: !nillable && !disabled && !noRequired,
    type: !encrypted ? 'text' : 'password',
    multiline: multiLine,
    rowsMax: lines,
    fullWidth: true,
    onOpen: () => setTouched(),
    clearable: nillable,
    cancelLabel: t('Cancel'),
    clearLabel: t('Clear'),
    emptyLabel: "",
    invalidLabel: t('err::invalid_date'),
    okLabel: t('Ok'),
    leftArrowIcon: React.createElement(ArrowLeft, null),
    rightArrowIcon: React.createElement(ArrowRight, null),
    InputLabelProps: {
      shrink: shrink ? true : undefined
    },
    InputProps: {
      autoFocus: !!autoFocus,
      disableUnderline: !underline,
      endAdornment: React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(IconButton, {
        disabled: disabled
      }, React.createElement(Event, null)))
    },
    DialogProps: {
      disablePortal: true
    }
  });
};
export default asField(DateFieldItem);