function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import round from 'lodash/fp/round';
import TextField from '@material-ui/core/TextField';
import withStyles from '@material-ui/styles/withStyles';
import { asField } from 'informed';
const rounding = round.convert({
  fixed: false
});

const styles = theme => ({
  numberInput: {
    textAlign: 'right',
    paddingRight: 8
  }
});

class DoubleFieldItem extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "handleBlur", e => {
      const {
        fieldApi: {
          setValue,
          setTouched
        },
        describe: {
          type
        },
        i18n: {
          language
        },
        currencyCode,
        onBlur,
        describe
      } = this.props;
      const {
        decimalSeparator,
        thousandSeparator
      } = this.state;
      const storageValue = toStored({
        value: e.target.value,
        decimalSeparator,
        thousandSeparator,
        type
      });
      setValue(storageValue);
      setTouched();
      this.setState({
        inputValue: toDisplay({
          value: storageValue,
          language,
          type,
          currencyCode
        })
      });

      if (onBlur) {
        onBlur(storageValue, e, describe);
      }
    });

    const {
      fieldState: {
        value
      },
      i18n: {
        language: _language
      },
      currencyCode: _currencyCode,
      describe: {
        type: _type
      }
    } = props;
    const val = !value && value !== 0 ? '' : value;

    const _decimalSeparator = 1.1.toLocaleString(_language).replace(/1/g, '');

    const _thousandSeparator = 1111 .toLocaleString(_language).replace(/1/g, '');

    this.state = {
      inputValue: toDisplay({
        value: val,
        language: _language,
        type: _type,
        currencyCode: _currencyCode
      }),
      decimalSeparator: _decimalSeparator,
      thousandSeparator: _thousandSeparator
    };
    this.handleBlur = this.handleBlur.bind(this);
  }

  render() {
    const {
      inputValue,
      decimalSeparator,
      thousandSeparator
    } = this.state;

    const _this$props = this.props,
          {
      fieldState,
      fieldApi,
      describe,
      t,
      classes,
      noRequired,
      isNewItem,
      currencyCode,
      shrink,
      underline,
      onChange,
      onBlur,
      autoFocus,
      rightJustifyNumeric
    } = _this$props,
          props = _objectWithoutProperties(_this$props, ["fieldState", "fieldApi", "describe", "t", "classes", "noRequired", "isNewItem", "currencyCode", "shrink", "underline", "onChange", "onBlur", "autoFocus", "rightJustifyNumeric"]);

    const {
      value,
      pristine,
      error
    } = fieldState;
    const {
      name,
      type,
      label,
      scale,
      nillable,
      encrypted,
      precision,
      createable,
      // createable and updateable determine if the field is enabled.
      updateable,
      defaultValue,
      inlineHelpText
    } = describe;
    let disabled = false;

    if (isNewItem && !createable) {
      disabled = true;
    }

    if (!isNewItem && !updateable) {
      disabled = true;
    }

    if (createable == null && updateable == null) {
      disabled = false;
    }

    const errors = error && !!error.length;
    const helperText = errors ? error.map(e => t(e)).join(', ') : null;
    let val = !value && value !== 0 ? '' : value;

    if (pristine && isNewItem) {
      val = defaultValue;
    }

    return React.createElement(TextField, {
      value: inputValue,
      disabled: disabled,
      error: errors,
      autoFocus: autoFocus,
      helperText: helperText // this goes below the line
      ,
      label: label,
      name: name,
      onChange: e => {
        this.setState({
          inputValue: e.target.value
        }); // setValue(toStored({ value: e.target.value, decimalSeparator, thousandSeparator, type }))
        // if (onChange) { onChange(toStored({ value: e.target.value, decimalSeparator, thousandSeparator, type }), e) }
        // setValue(e.target.value)

        if (onChange) {
          onChange(toStored({
            value: e.target.value,
            decimalSeparator,
            thousandSeparator,
            type
          }), e, describe);
        }
      },
      onBlur: this.handleBlur,
      onKeyDown: e => {
        if (e.key === 'Enter') {
          this.handleBlur(e);
        }
      },
      placeholder: inlineHelpText,
      required: !nillable && !disabled && !noRequired,
      type: !encrypted ? 'text' : 'password',
      fullWidth: true,
      InputLabelProps: {
        shrink: shrink ? true : undefined
      },
      InputProps: {
        disableUnderline: !underline,
        classes: {
          input: rightJustifyNumeric ? classes.numberInput : ''
        }
      }
    });
  }

}

export default asField(withStyles(styles)(DoubleFieldItem));

function toDisplay({
  value,
  language,
  type,
  currencyCode = 'USD'
}) {
  const localeType = type !== 'decimal' && type !== 'percent' && type !== 'currency' ? 'decimal' : type;

  if (type === 'percent') {
    // Trim off dangling .0000000001
    value = rounding(value / 100, 6);
  }

  return value.toLocaleString(language, {
    maximumFractionDigits: 20,
    style: localeType,
    currency: currencyCode,
    currencyDisplay: 'symbol'
  });
}

function toStored({
  value,
  decimalSeparator,
  thousandSeparator,
  type
}) {
  let returnValue = value.replace(decimalSeparator, '.').replace(thousandSeparator, '');
  returnValue = returnValue.replace(/[^0-9.e+-]/g, '').replace(/^[.e+-]+$/, '');

  if (returnValue) {
    returnValue = parseFloat(returnValue);
  }

  if ((returnValue || returnValue === 0) && type === 'percent') {// returnValue /= 100
  }

  return returnValue;
}