function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useState, useEffect } from 'react';
import { makeStyles } from '@material-ui/styles';
import MenuItem from '@material-ui/core/MenuItem';
import Checkbox from '@material-ui/core/Checkbox';
import ListItemText from '@material-ui/core/ListItemText';
import InputLabel from '@material-ui/core/InputLabel';
import FormControl from '@material-ui/core/FormControl';
import Select from '@material-ui/core/Select';
import FormHelperText from '@material-ui/core/FormHelperText';
import Chip from '@material-ui/core/Chip';
import TextField from '@material-ui/core/TextField';
import IconButton from '@material-ui/core/IconButton';
import { asField } from 'informed';
import Check from '@material-ui/icons/Check';
import getColor from '../../utils/picklistColor';
const useClasses = makeStyles(theme => ({
  formControl: {
    width: '100%'
  }
}));

function PicklistFieldItem(_ref) {
  let {
    fieldState,
    fieldApi,
    describe,
    t,
    i18n,
    noRequired,
    isNewItem,
    maxLines,
    shrink,
    underline
  } = _ref,
      props = _objectWithoutProperties(_ref, ["fieldState", "fieldApi", "describe", "t", "i18n", "noRequired", "isNewItem", "maxLines", "shrink", "underline"]);

  const [menuOpen, setMenuOpen] = useState(!!props.autoFocus);
  const [loading, setLoading] = useState(true);
  const {
    value,
    pristine,
    error
  } = fieldState;
  const {
    setValue,
    setTouched
  } = fieldApi;
  const {
    onChange,
    onBlur,
    autoFocus,
    onClose = () => {}
  } = props;
  const {
    name,
    type,
    label,
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    picklistValues = [],
    restrictedPicklist = true,
    inlineHelpText,
    deprecatedAndHidden // if this is true this component should not return anything. - Grid

  } = describe;
  const classes = useClasses();
  const initComboValue = picklistValues.map(pv => pv.value).includes(value) ? '' : value || '';
  const [comboValue, setComboValue] = useState(initComboValue);
  let disabled = false;

  if (isNewItem && !createable) {
    disabled = true;
  }

  if (!isNewItem && !updateable) {
    disabled = true;
  }

  if (createable == null && updateable == null) {
    disabled = false;
  }

  const errors = error && !!error.length;
  const helperText = errors ? error.map(e => t(e)).join(', ') : null;
  let val = !value && value !== 0 ? '' : value;

  if (pristine && isNewItem) {
    val = defaultValue;
  }

  const multiple = type === 'multipicklist';

  if (multiple && !Array.isArray(val)) {
    val = val.split(';');
  }

  useEffect(() => {
    setTimeout(() => setLoading(false), 1);
  }, []);

  function handleChange(event) {
    const value = event.target.value;
    const valueString = Array.isArray(value) ? value.filter(v => v).join(';').trim(';') : value || '';
    setValue(valueString);
    setTouched();

    if (onChange) {
      onChange(valueString, _objectSpread({}, event, {
        target: _objectSpread({}, event.target, {
          value: valueString
        })
      }), describe);
    }
  }

  function handleMenuClose() {
    setMenuOpen(false);

    if (autoFocus) {
      handleBlur({
        target: null
      });
      onClose();
    }
  }

  function handleBlur(event) {
    if (loading) {
      return;
    }

    const valueString = value;

    if (onBlur) {
      onBlur(valueString, _objectSpread({}, event, {
        target: _objectSpread({}, event.target, {
          value: valueString
        })
      }), describe);
    }
  }

  return React.createElement(FormControl, {
    className: classes.formControl
  }, React.createElement(InputLabel, null, label), React.createElement(Select, {
    autoFocus: false,
    disabled: disabled,
    multiple: multiple,
    value: val || '',
    required: !nillable,
    onChange: handleChange,
    onBlur: handleBlur,
    onOpen: () => setMenuOpen(true),
    open: !!menuOpen,
    onClose: handleMenuClose,
    fullWidth: true,
    renderValue: selected => {
      const mySelected = Array.isArray(selected) ? selected.filter(s => s) : [selected].filter(s => s);
      const selectedLabels = mySelected.map(ms => picklistValues.find(pv => pv.value === ms) || {
        value: ms,
        label: ms
      });
      return React.createElement("div", {
        className: classes.chips
      }, selectedLabels.map(sl => {
        const colors = getColor(sl.value, picklistValues);
        return React.createElement(Chip, {
          key: sl.value,
          label: sl.label,
          style: {
            color: colors[0],
            backgroundColor: colors[1]
          }
        });
      }));
    },
    MenuProps: {
      disablePortal: true,
      autoFocus: true,
      onKeyDown: e => {
        if (e.key !== 'Escape') {
          // Need to pass through the escape key for datagrid
          e.stopPropagation();
        }
      }
    },
    error: errors
  }, type !== 'multipicklist' && React.createElement(MenuItem, {
    value: ""
  }, React.createElement(ListItemText, {
    primary: t('NoValue')
  })), !restrictedPicklist && React.createElement(MenuItem, {
    value: comboValue
  }, React.createElement(TextField, {
    value: comboValue,
    autoFocus: true,
    fullWidth: true,
    onClick: e => e.stopPropagation(),
    onChange: e => setComboValue(e.target.value),
    onKeyDown: e => e.stopPropagation()
  }), React.createElement(IconButton, null, React.createElement(Check, null))), picklistValues.map(pv => {
    const selected = multiple ? val.includes(pv.value) : val === pv.value;
    return React.createElement(MenuItem, {
      key: pv.value,
      value: pv.value
    }, multiple && React.createElement(Checkbox, {
      checked: selected
    }), React.createElement(ListItemText, {
      primary: pv.label
    }));
  })), helperText && React.createElement(FormHelperText, null, helperText));
}

export default asField(PicklistFieldItem);