function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { asField } from 'informed';
import Downshift from 'downshift';
import TextField from '@material-ui/core/TextField';
import SelectionPaper from './SelectionPaper';
import SelectionItem from './SelectionItem';
import QueryManager from './QueryManager';
export class ReferenceFieldItem extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "state", {
      item: {
        label: ''
      },
      inputValue: ''
    });

    this.handleChange = this.handleChange.bind(this);
    this.handleInputChange = this.handleInputChange.bind(this);
    this.suggestionRef = React.createRef();
  }

  async componentDidMount() {
    // need to lookup the itemId
    const {
      fieldState: {
        value
      },
      lookup,
      describe // describe: { primaryFields, secondaryFields },

    } = this.props;

    if (typeof lookup === 'function' && value) {
      const item = await lookup(value, describe.name, describe);

      if (item) {
        this.setState({
          item
        });
      }
    }
  }

  handleChange(item) {
    const {
      onChange,
      onBlur,
      lookupIdFromItem,
      fieldApi: {
        setValue
      },
      describe
    } = this.props;

    if (!item || !item.itemId) {
      item = {};
    }

    const value = lookupIdFromItem(item);
    setValue(value);
    this.setState({
      item
    });

    if (onChange) {
      onChange(value, item, describe);
    }

    if (onBlur) {
      onBlur(value, item, describe);
    }
  }

  handleInputChange(inputValue) {
    this.setState({
      inputValue
    });
  }

  handleClose() {
    const {
      onClose
    } = this.props;

    if (typeof onClose === 'function') {
      onClose();
    }
  }

  render() {
    const {
      t,
      i18n,
      shrink,
      describe,
      fieldApi,
      noRequired,
      isNewItem,
      underline,
      fieldState,
      // onChange,
      // onBlur,
      autoFocus,
      lookupQry,
      variant,
      variantClasses
    } = this.props;
    const {
      value,
      pristine,
      error
    } = fieldState; // const { setValue, setTouched } = fieldApi

    const {
      name,
      type,
      label,
      nillable,
      createable,
      // createable and updateable determine if the field is enabled.
      updateable,
      defaultValue,
      extraTypeInfo,
      // e.g text area and rich text area are about the same. This would say rich text area to differentiate
      referenceTo,
      inlineHelpText,
      deprecatedAndHidden // if this is true this component should not return anything. - Grid

    } = describe;
    let disabled = false;

    if (isNewItem && !createable) {
      disabled = true;
    }

    if (!isNewItem && !updateable) {
      disabled = true;
    }

    if (createable == null && updateable == null) {
      disabled = false;
    }

    const errors = error && !!error.length;
    const helperText = errors ? error.map(e => t(e)).join(', ') : null; // let val = (!value && value !== 0 ? '' : value)
    // if (pristine && isNewItem) { val = defaultValue }
    // val is the itemId
    // selectedItem is this.state.item

    return React.createElement(Downshift, {
      itemToString: item => !item ? '' : item.label,
      inputValue: this.state.inputValue || '',
      selectedItem: this.state.item,
      onInputValueChange: this.handleInputChange,
      onChange: this.handleChange
    }, ({
      getInputProps,
      getItemProps,
      isOpen,
      inputValue,
      selectedItem,
      highlightedIndex
    }) => React.createElement("div", {
      style: {
        width: '100%'
      }
    }, React.createElement(TextField, _extends({
      autoFocus: autoFocus,
      value: inputValue,
      disabled: disabled,
      error: errors,
      helperText: helperText,
      label: label,
      placeholder: inlineHelpText,
      required: !nillable && !disabled && !noRequired
    }, getInputProps({
      onKeyDown: e => {
        if (isOpen) {
          e.stopPropagation();
        } else if (e.key === 'Enter') {
          this.handleClose();
        }
      }
    }), {
      fullWidth: true,
      InputLabelProps: {
        shrink: shrink ? true : undefined
      },
      InputProps: {
        disableUnderline: !underline,
        onFocus: e => {
          e.persist();
          setTimeout(() => e.target.select(), 1);
        } // ref: this.suggestionRef,
        // onKeyDown: e => {
        //   if (e.key === 'Escape') {
        //     return this.handleChange(this.state.item)
        //   }
        //   if (e.key === 'Enter' && !e.target.value) {
        //     return this.handleChange({}) // set back to undefined
        //   }
        //   if (e.key === 'Enter') {
        //     this.handleChange(this.state.item)
        //   }
        // },

      }
    })), isOpen && React.createElement(QueryManager, {
      nullLabel: t('none'),
      fieldName: name,
      itemTypes: referenceTo,
      lookupQry: lookupQry,
      inputValue: inputValue
    }, queryResults => React.createElement("div", {
      ref: this.suggestionRef,
      style: {
        position: 'relative'
      }
    }, React.createElement(SelectionPaper, _extends({
      anchorEl: this.suggestionRef,
      t: t
    }, queryResults), queryResults && queryResults.data && queryResults.data.map((item, index) => React.createElement(SelectionItem, _extends({
      key: item ? item.itemId : Math.random(),
      item: item
    }, getItemProps({
      item,
      index,
      isActive: highlightedIndex === index,
      isSelected: selectedItem && item && selectedItem.itemId === item.itemId
    })))))))));
  }

}
export default asField(ReferenceFieldItem);