import React from 'react';
import Paper from '@material-ui/core/Paper';
import Popper from '@material-ui/core/Popper';
import withStyles from '@material-ui/styles/withStyles';

const styles = theme => ({
  root: {
    position: 'absolute',
    zIndex: theme.zIndex.tooltip,
    minWidth: '100%',
    display: 'flex',
    justifyContent: 'center'
  },
  message: {
    margin: theme.spacing(2)
  }
});

const SelectionPaper = ({
  t,
  anchorEl,
  classes,
  children,
  data,
  loading,
  error
}) => {
  let message = children;

  if (loading) {
    message = React.createElement("div", {
      className: classes.message
    }, t('loading'));
  } else if (error) {
    message = React.createElement("div", {
      className: classes.message
    }, t(error));
  } else if (!data) {
    message = React.createElement("div", {
      className: classes.message
    }, t('noResults'));
  } else if (data.length === 1) {
    message = React.createElement(React.Fragment, null, message, React.createElement("div", {
      className: classes.message
    }, t('noResults')));
  }

  return React.createElement(Popper, {
    open: Boolean(anchorEl.current),
    anchorEl: anchorEl.current,
    className: classes.root,
    placement: "bottom-start",
    disablePortal: true,
    modifiers: {
      flip: {
        enabled: true
      },
      preventOverflow: {
        enabled: true,
        boundariesElement: 'scrollParent'
      }
    }
  }, React.createElement(Paper, {
    style: {
      marginBottom: 34,
      minWidth: 400,
      width: 400,
      minHeight: 34,
      maxWidth: 400
    }
  }, message));
};

export default withStyles(styles)(SelectionPaper);