function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import TextField from '@material-ui/core/TextField';
import Grid from '@material-ui/core/Grid';
import { asField } from 'informed';
import FilterFieldContainer from '../../utils/FilterFieldContainer';
import stringDropdownItems from '../../utils/stringDropdownItems';
const filters = {
  'Contains': [{
    type: 'TextField',
    label: 'Contains',
    key: '$contains'
  }],
  'Exactly': [{
    type: 'TextField',
    label: 'Exactly',
    key: '$like'
  }],
  'Starts With': [{
    type: 'TextField',
    label: 'beginsWith',
    key: '$beginsWith'
  }],
  'Ends With': [{
    type: 'TextField',
    label: 'EndsWith',
    key: '$endsWith'
  }],
  'HasAnyValue': [{
    type: 'Text',
    label: 'HasAnyValue',
    key: '$exists'
  }],
  'HasNoValue': [{
    type: 'Text',
    label: 'HasNoValue',
    key: '$exists'
  }]
};

class StringFilterFieldItem extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      filterType: this.props.fieldState.value && this.props.fieldState.value.type || 'Contains',
      $contains: this.props.fieldState.value && this.props.fieldState.value.$contains || undefined,
      $like: this.props.fieldState.value && this.props.fieldState.value.$like || undefined,
      $beginsWith: this.props.fieldState.value && this.props.fieldState.value.$beginsWith || undefined,
      $endsWith: this.props.fieldState.value && this.props.fieldState.value.$endsWith || undefined,
      $exact: this.props.fieldState.value && this.props.fieldState.value.$exact || undefined,
      $exists: this.props.fieldState.value && this.props.fieldState.value.$exists || undefined
    });
  }

  handleSetValue() {
    this.props.fieldApi.setValue({
      type: this.state.filterType,
      $contains: this.state.$contains,
      $like: this.state.$like,
      $beginsWith: this.state.$beginsWith,
      $endsWith: this.state.$endsWith,
      $exact: this.state.$exact,
      $exists: this.state.$exists
    });
  }

  handleChangeFilter(filter) {
    this.setState({
      filterType: filter,
      $contains: undefined,
      $like: undefined,
      $beginsWith: undefined,
      $endsWith: undefined,
      $exact: undefined,
      $exists: filter === 'HasAnyValue' || filter === 'HasNoValue' ? filter === 'HasAnyValue' : undefined
    }, () => this.handleSetValue());
  }

  handleOnChange(key, value) {
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  handleOnBlur(key, value) {
    this.props.fieldApi.setTouched();
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  render() {
    const _this$props = this.props,
          {
      fieldState,
      fieldApi,
      describe,
      t,
      i18n,
      shrink,
      underline,
      spacing
    } = _this$props,
          props = _objectWithoutProperties(_this$props, ["fieldState", "fieldApi", "describe", "t", "i18n", "shrink", "underline", "spacing"]);

    const {
      value
    } = fieldState;
    const {
      setValue,
      setTouched
    } = fieldApi;
    const {
      onChange,
      onBlur
    } = props;
    const {
      filterType
    } = this.state;
    return React.createElement(FilterFieldContainer, {
      t: t,
      filterList: stringDropdownItems,
      filterChange: filter => this.handleChangeFilter(filter)
    }, React.createElement(Grid, {
      container: true,
      spacing: spacing,
      alignItems: "flex-end"
    }, React.createElement(Grid, {
      item: true,
      xs: 4
    }, describe.label, ":"), filters[filterType] && filters[filterType].map(ft => {
      const filterColumns = filters[filterType].length > 2 ? 2 : filters[filterType].length;

      if (ft.type === 'TextField') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, React.createElement(FieldItemIndividual, {
          label: t(ft.label),
          describe: describe,
          value: this.state[ft.key] ? this.state[ft.key] : '',
          onChange: value => this.handleOnChange(ft.key, value),
          onBlur: value => this.handleOnBlur(ft.key, value),
          shrink: shrink,
          underline: underline
        }));
      }

      if (ft.type === 'Text') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, ft.label);
      }

      return 'err::invalidFilterType';
    })));
  }

}

export default asField(StringFilterFieldItem);

function FieldItemIndividual({
  label,
  value,
  onChange,
  onBlur,
  describe,
  shrink,
  underline
}) {
  const {
    name,
    type,
    // label, // not used in filter
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    encrypted,
    bytelength,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    extraTypeInfo,
    // e.g text area and rich text area are about the same. This would say rich text area to differentiate
    inlineHelpText,
    deprecatedAndHidden // if this is true this component should not return anything. - Grid

  } = describe;
  return React.createElement(TextField, {
    value: value,
    label: label,
    name: name,
    placeholder: inlineHelpText,
    InputLabelProps: {
      shrink: shrink ? true : undefined
    },
    InputProps: {
      disableUnderline: !underline
    },
    onChange: e => onChange(e.target.value),
    onBlur: e => onBlur(e.target.value),
    fullWidth: true
  });
}