function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import TextField from '@material-ui/core/TextField';
import { asField } from 'informed';
import Tooltip from '@material-ui/core/Tooltip';
import InfoIcon from '@material-ui/icons/Info';
export const StringFieldItem = (_ref) => {
  let {
    fieldState,
    fieldApi,
    describe,
    t,
    i18n,
    noRequired,
    isNewItem,
    shrink,
    underline
  } = _ref,
      props = _objectWithoutProperties(_ref, ["fieldState", "fieldApi", "describe", "t", "i18n", "noRequired", "isNewItem", "shrink", "underline"]);

  const {
    value,
    pristine,
    error
  } = fieldState;
  const {
    setValue,
    setTouched
  } = fieldApi;
  const {
    onChange,
    onBlur,
    autoFocus
  } = props;
  const {
    name,
    type,
    label,
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    encrypted,
    bytelength,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    extraTypeInfo,
    // e.g text area and rich text area are about the same. This would say rich text area to differentiate
    inlineHelpText,
    deprecatedAndHidden,
    // if this is true this component should not return anything. - Grid
    requirements
  } = describe;
  let disabled = false;

  if (isNewItem && !createable) {
    disabled = true;
  }

  if (!isNewItem && !updateable) {
    disabled = true;
  }

  if (createable == null && updateable == null) {
    disabled = false;
  }

  const errors = error && !!error.length;
  const helperText = errors ? error.map(e => t(e)).join(', ') : null;
  const maxLines = type === 'textarea' ? 12 : 1;
  const multiLine = parseInt(maxLines, 10) > 1 || false;
  const lines = parseInt(maxLines, 10) || 1;
  const fieldType = encrypted || type === 'password' || type === 'encryptedString';
  let val = !value && value !== 0 ? '' : value;

  if (pristine && isNewItem) {
    val = defaultValue;
  }

  return React.createElement(TextField, {
    autoFocus: autoFocus,
    value: val,
    disabled: disabled,
    error: errors,
    helperText: helperText // this goes below the line
    ,
    label: label,
    name: name,
    onChange: e => {
      setValue(e.target.value);

      if (onChange) {
        onChange(e.target.value, e, describe);
      }
    },
    onBlur: e => {
      setTouched();

      if (onBlur) {
        onBlur(e.target.value, e, describe);
      }
    },
    onKeyDown: e => {
      if (!multiLine && e.key === 'Enter') {
        setValue(e.target.value);
        setTouched();

        if (onBlur) {
          onBlur(e.target.value, e, describe);
        }
      }
    },
    placeholder: inlineHelpText,
    required: !nillable && !disabled && !noRequired,
    type: !fieldType ? 'text' : 'password',
    multiline: multiLine,
    rowsMax: lines,
    fullWidth: true,
    InputLabelProps: {
      shrink: shrink ? true : undefined
    },
    InputProps: {
      disableUnderline: !underline,
      endAdornment: requirements && fieldType ? React.createElement(RequirementIcon, {
        requirements: requirements
      }) : undefined
    }
  });
};
export default asField(StringFieldItem);

function RequirementIcon({
  requirements
}) {
  return React.createElement(Tooltip, {
    title: requirements
  }, React.createElement(InfoIcon, {
    fontSize: "small"
  }));
}