function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import Grid from '@material-ui/core/Grid';
import { asField } from 'informed';
import { TimePicker } from '@material-ui/pickers';
import { DateTime } from 'luxon';
import InputAdornment from '@material-ui/core/InputAdornment';
import IconButton from '@material-ui/core/IconButton';
import Schedule from '@material-ui/icons/Schedule';
import FilterFieldContainer from '../../utils/FilterFieldContainer';
import dateDropdownItems from '../../utils/dateDropdownItems';
import semanticList from '../../utils/semanticList';
const filters = {
  Between: [{
    type: 'TextField',
    label: 'GreaterThan',
    key: '$gte'
  }, {
    type: 'TextField',
    label: 'LessThan',
    key: '$lte'
  }],
  Outside: [{
    type: 'TextField',
    label: 'LessThan',
    key: '$lte'
  }, {
    type: 'TextField',
    label: 'GreaterThan',
    key: '$gte'
  }],
  'Greater Than': [{
    type: 'TextField',
    label: 'Greater Than',
    key: '$gte'
  }],
  'Less Than': [{
    type: 'TextField',
    label: 'Less Than',
    key: '$lte'
  }],
  'HasAnyValue': [{
    type: 'Text',
    label: 'HasAnyValue',
    key: '$exists'
  }],
  'HasNoValue': [{
    type: 'Text',
    label: 'HasNoValue',
    key: '$exists'
  }],
  Exactly: [{
    type: 'TextField',
    label: 'Exactly',
    key: '$exact'
  }]
};

class TimeFilterFieldItem extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      filterType: this.props.fieldState.value && this.props.fieldState.value.type || 'Between',
      $gte: this.props.fieldState.value && this.props.fieldState.value.$gte || undefined,
      $lte: this.props.fieldState.value && this.props.fieldState.value.$lte || undefined,
      $exact: this.props.fieldState.value && this.props.fieldState.value.$exact || undefined,
      $exists: this.props.fieldState.value && this.props.fieldState.value.$exists || undefined
    });
  }

  handleSetValue() {
    this.props.fieldApi.setValue({
      type: this.state.filterType,
      $gte: this.state.$gte,
      $lte: this.state.$lte,
      $exact: this.state.$exact,
      $exists: this.state.$exists
    });
  }

  handleChangeFilter(filter) {
    this.setState({
      filterType: filter,
      $gte: undefined,
      $lte: undefined,
      $exact: undefined,
      $exists: filter === 'HasAnyValue' || filter === 'HasNoValue' ? filter === 'HasAnyValue' : undefined
    }, () => this.handleSetValue());
  }

  handleOnChange(key, value) {
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  handleOnBlur(key, value) {
    this.props.fieldApi.setTouched();
    this.setState({
      [key]: value
    }, () => {
      this.handleSetValue();
    });
  }

  render() {
    const _this$props = this.props,
          {
      fieldState,
      fieldApi,
      describe,
      t,
      i18n,
      shrink,
      underline,
      spacing
    } = _this$props,
          props = _objectWithoutProperties(_this$props, ["fieldState", "fieldApi", "describe", "t", "i18n", "shrink", "underline", "spacing"]);

    const {
      value
    } = fieldState;
    const {
      setValue,
      setTouched
    } = fieldApi;
    const {
      onChange,
      onBlur
    } = props;
    const {
      filterType
    } = this.state;
    return React.createElement(FilterFieldContainer, {
      t: t,
      filterList: dateDropdownItems,
      filterChange: filter => this.handleChangeFilter(filter)
    }, React.createElement(Grid, {
      container: true,
      spacing: spacing,
      alignItems: "flex-end"
    }, React.createElement(Grid, {
      item: true,
      xs: 4
    }, describe.label, ":"), filters[filterType] && filters[filterType].map(ft => {
      const filterColumns = filters[filterType].length > 2 ? 2 : filters[filterType].length;

      if (ft.type === 'TextField') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, React.createElement(FieldItemIndividual, {
          t: t,
          label: t(ft.label),
          describe: describe,
          value: this.state[ft.key] ? this.state[ft.key] : '',
          onChange: value => this.handleOnChange(ft.key, value),
          onBlur: value => this.handleOnBlur(ft.key, value),
          shrink: shrink,
          underline: underline
        }));
      }

      if (ft.type === 'Text') {
        return React.createElement(Grid, {
          item: true,
          key: ft.key,
          xs: 8 / filterColumns
        }, ft.label);
      }

      return 'err::invalidFilterType';
    })));
  }

}

export default asField(TimeFilterFieldItem);

function FieldItemIndividual({
  t,
  label,
  value,
  onChange,
  onBlur,
  describe,
  shrink,
  underline
}) {
  const {
    name,
    type,
    // label, // not used in filter
    length,
    // may be used for fullWidth - In the grid component?
    nillable,
    encrypted,
    bytelength,
    createable,
    // createable and updateable determine if the field is enabled.
    updateable,
    defaultValue,
    extraTypeInfo,
    // e.g text area and rich text area are about the same. This would say rich text area to differentiate
    inlineHelpText,
    deprecatedAndHidden // if this is true this component should not return anything. - Grid

  } = describe;
  let val = value;

  if (!val || val === '') {
    val = null;
  }

  if (val && val.charAt(1) === ':') {
    val = `0${val}`;
  }

  if (val) {
    val = DateTime.fromISO(val.replace('Z', '+00:00')).toLocal();
  }

  return React.createElement(TimePicker, {
    value: val,
    label: label,
    name: name,
    format: "t",
    onChange: e => {
      onChange(e ? e.setZone('utc').toJSON().replace(/.*T/, '') : '');
    },
    placeholder: inlineHelpText,
    type: !encrypted ? 'text' : 'password',
    fullWidth: true,
    autoOk: true,
    clearable: nillable,
    cancelLabel: t('Cancel'),
    clearLabel: t('Clear'),
    emptyLabel: "",
    invalidLabel: t('err::invalid_date'),
    okLabel: t('Ok'),
    InputLabelProps: {
      shrink: shrink ? true : undefined
    },
    InputProps: {
      disableUnderline: !underline,
      endAdornment: React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(IconButton, null, React.createElement(Schedule, null)))
    }
  });
}